﻿using System;
using System.Windows.Forms;

using Steema.TeeChart;
using Steema.TeeChart.Functions;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 캔들 시리즈
        /// </summary>
        private Candle candle = new Candle();

        /// <summary>
        /// RVI 함수
        /// </summary>
        private RVIFunction rviFunction = new RVIFunction();

        /// <summary>
        /// 라인 시리즈
        /// </summary>
        private Line line = new Line();

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 축을 생성한다.

            Axis axis = new Axis(this.tChart.Chart);

            axis.Horizontal    = false;
            axis.StartPosition = 52;
            axis.EndPosition   = 100;

            #endregion
            #region RVI 함수를 설정한다.

            this.rviFunction.Period = 10;

            #endregion
            #region 라인 시리즈를 설정한다.

            this.line.CustomVertAxis = axis;
            this.line.DataSource     = this.candle;
            this.line.Function       = this.rviFunction;

            #endregion
            #region 티차트를 설정한다.

            this.tChart.Header.Text           = "RVI(10)";
            this.tChart.Axes.Left.EndPosition = 48;

            this.tChart.Axes.Custom.Add(axis);

            this.tChart.Series.Add(candle);
            this.tChart.Series.Add(line);

            #endregion

            this.candle.FillSampleValues(200);

            this.periodNumericUpDown.ValueChanged      += periodNumericUpDown_ValueChanged;
            this.showSignalLineCheckBox.CheckedChanged += showSignalLineCheckBox_CheckedChanged;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 기간 숫자 UP/DOWN 값 변경시 처리하기 - periodNumericUpDown_ValueChanged(sender, e)

        /// <summary>
        /// 기간 숫자 UP/DOWN 값 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void periodNumericUpDown_ValueChanged(object sender, EventArgs e)
        {
            this.line.Function.Period = (double)this.periodNumericUpDown.Value;

            this.tChart.Header.Text = $"RVI({this.line.Function.Period})";
        }

        #endregion
        #region 시그널 라인 표시 체크 박스 체크 변경시 처리하기 - showSignalLineCheckBox_CheckedChanged(sender, e)

        /// <summary>
        /// 시그널 라인 표시 체크 박스 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void showSignalLineCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.rviFunction.Signal.Visible = this.showSignalLineCheckBox.Checked; 
        }

        #endregion
    }
}